@@ -1,9 +1,9 @@
 /*
  * ataidentify.cpp
  *
- * Home page of code is: http://www.smartmontools.org
+ * Home page of code is: https://www.smartmontools.org
  *
- * Copyright (C) 2012-18 Christian Franke
+ * Copyright (C) 2012-21 Christian Franke
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -13,7 +13,7 @@
 
 #include "ataidentify.h"
 
-const char * ataidentify_cpp_cvsid = "$Id: ataidentify.cpp 4760 2018-08-19 18:45:53Z chrfranke $"
+const char * ataidentify_cpp_cvsid = "$Id: ataidentify.cpp 5227 2021-06-26 15:20:41Z chrfranke $"
   ATAIDENTIFY_H_CVSID;
 
 #include "utility.h"
@@ -30,6 +30,7 @@ const char * ataidentify_cpp_cvsid = "$Id: ataidentify.cpp 4760 2018-08-19 18:45
 // Tables 50 and 61 of T13/2015-D (ACS-2) Revision 7, June 22, 2011
 // Tables 45 and 50 of T13/2161-D (ACS-3) Revision 5, October 28, 2013
 // Table 55 of T13/BSR INCITS 529 (ACS-4) Revision 20, October 26, 2017 (ATAPI removed)
+// Table 57 of T13/BSR INCITS 558 (ACS-5) Revision 10, March 3, 2021
 
 const char * const identify_descriptions[] = {
   "  0 General configuration",
@@ -113,7 +114,7 @@ const char * const identify_descriptions[] = {
     ". 14 OVERWRITE EXT supported",
     ". 13 CRYPTO SCRAMBLE EXT supported",
     ". 12 Sanitize Device feature set supported",
-    ". 11 Cmds during sanitize as specified by this standard", // ACS-3
+    ". 11 Cmds during sanitize are as specified by ACS-3", // ACS-3
     ". 10 SANITIZE ANTIFREEZE LOCK EXT supported", // ACS-3
     ". 9 Reserved",
     ". 8 Bits 7:0 are valid [OBS-ACS-4]",
@@ -157,7 +158,7 @@ const char * const identify_descriptions[] = {
     ". 4 Device encrypts all user data",
     ". 3 Extended number of user addressable sectors supported",
     ". 2 All write cache is non-volatile", // ACS-3
-    ". 1:0 Zoned Capabilities", // ACS-4
+    ". 1:0 Zoned Capabilities [OBS-ACS-5]", // ACS-4
 
   " 70 Reserved",
   " 71-74 ATA: Reserved for IDENTIFY PACKET DEVICE",
@@ -185,7 +186,8 @@ const char * const identify_descriptions[] = {
     ". 0 Must be set to 0",
 
   " 77 Serial ATA additional capabilities", // ACS-3
-    ". 15:9 Reserved for Serial ATA",
+    ". 15:10 Reserved for Serial ATA",
+    ". 9 Out Of Band Management supported", // ACS-5
     ". 8 Power Disable feature always enabled", // ACS-4
     ". 7 DevSleep to ReducedPwrState supported", // ACS-4
     ". 6 RECEIVE/SEND FPDMA QUEUED supported",
@@ -226,7 +228,8 @@ const char * const identify_descriptions[] = {
     ". 0 Must be set to 0",
 
   " 80 Major version number",
-    ". 15:12 Reserved",
+    ". 15:13 Reserved",
+    ". 12 ACS-5 supported",
     ". 11 ACS-4 supported",
     ". 10 ACS-3 supported",
     ". 9 ACS-2 supported",
@@ -390,7 +393,7 @@ const char * const identify_descriptions[] = {
     ". 4 Device 0 detected the assertion of PDIAG-",
     ". 3 Device 0 passed diagnostics",
     ". 2:1 Device 0 detection method: -, Jumper, CSEL, other",
-    ". 0 Must be set to 1",
+    ". 0 Must be set to 1 for PATA devices",
 
   " 94 AAM level [OBS-ACS-2]",
     ". 15:8 Recommended AAM level [OBS-ACS-2]",
@@ -533,7 +536,9 @@ const char * const identify_descriptions[] = {
 
   "222 Transport major version number",
     ". 15:12 Transport: 0x0 = Parallel, 0x1 = Serial, 0xe = PCIe", // PCIe: ACS-4
-    ". 11:9 Reserved    | Reserved",
+    ". 11 Reserved    | Reserved",
+    ". 10 Reserved    | SATA 3.5", // ACS-5
+    ". 9 Reserved    | SATA 3.4", // ACS-5
     ". 8 Reserved    | SATA 3.3", // ACS-4
     ". 7 Reserved    | SATA 3.2", // ACS-4
     ". 6 Reserved    | SATA 3.1", // ACS-3
